@@ -3,15 +3,17 @@
 //! # Stack
 //!
 //! `stacking` comes with a [`Stack`] builtin.
-//! It only supports `pop` and `push` as actions
+//! It only supports `pop`, `push` and `len` as actions
 //!
 //! ## Examples
 //!
 //! ```rust
 //! use stacking::stacks::Stack;
 //!
-//! let mut stack: Stack<i32> = Stack::new(0);
+//! let mut stack: Stack<i32> = Stack::new();
+//! assert_eq!(stack.len(), 0);
 //! stack.push(4);
+//! assert_eq!(stack.len(), 1);
 //! assert_eq!(stack.pop(), Some(4));
 //! ```
 //!
@@ -45,14 +47,22 @@ mod tests {
     use crate::stacks::Stack;
     #[test]
     fn stack_push_pop() {
-        let mut stack: Stack<i32> = Stack::new(0);
+        let mut stack: Stack<i32> = Stack::new();
         stack.push(4);
         assert_eq!(stack.pop(), Some(4));
     }
 
     #[test]
     fn empty_stack_pop() {
-        let mut stack: Stack<i32> = Stack::new(0);
+        let mut stack: Stack<i32> = Stack::new();
         assert_eq!(stack.pop(), None);
     }
+
+    #[test]
+    fn stack_len() {
+        let mut stack: Stack<i32> = Stack::new();
+        assert_eq!(stack.len(), 0);
+        stack.push(4);
+        assert_eq!(stack.len(), 1);
+    }
 }
