@@ -43,7 +43,8 @@ pub mod stacks {
     /// A stack is handled as a collection of nodes.
     /// we specify the top node who himself specifies the previous node and so on.
     pub struct Stack<T: std::clone::Clone> {
-        top: Node<T>,
+        top: Option<Node<T>>,
+        len: usize,
     }
 
     impl<T: std::clone::Clone> Stack<T> {
@@ -56,10 +57,8 @@ pub mod stacks {
         /// # Returns
         ///
         /// this function returns a new stack with one node that has the value of `val`
-        pub fn new(val: T) -> Stack<T> {
-            Stack {
-                top: Node::new(None, None, val),
-            }
+        pub fn new() -> Stack<T> {
+            Stack { top: None, len: 0 }
         }
 
         /// push a new element to the stack
@@ -73,20 +72,17 @@ pub mod stacks {
         /// ```rust
         /// use stacking::stacks::Stack;
         ///
-        /// let mut stack: Stack<i32> = Stack::new(0);
+        /// let mut stack: Stack<i32> = Stack::new();
         /// stack.push(4);
         /// assert_eq!(stack.pop(), Some(4));
         /// ```
         pub fn push(&mut self, val: T) {
-            let new_top: Node<T> = Node::new(None, Some(self.top.clone()), val);
-            self.top = new_top;
+            let new_top: Node<T> = Node::new(None, self.top.clone(), val);
+            self.top = Some(new_top);
+            self.len += 1;
         }
 
         /// pop the top element of the stack.
-        /// Note that a stack must always have at least one element.
-        /// Therefore if you initialize a stack with one value and then add another value
-        /// and pop twice the first one will succeed but the second one will fail
-        ///
         ///
         /// # Returns
         ///
@@ -97,21 +93,53 @@ pub mod stacks {
         /// ```rust
         /// use stacking::stacks::Stack;
         ///
-        /// let mut stack: Stack<i32> = Stack::new(0);
+        /// let mut stack: Stack<i32> = Stack::new();
         /// stack.push(4);
         /// stack.push(5);
         /// assert_eq!(stack.pop(), Some(5));
         /// assert_eq!(stack.pop(), Some(4));
         /// ```
         pub fn pop(&mut self) -> Option<T> {
-            let retval = self.top.val.clone();
-            if let None = *self.top.prev {
+            if self.len == 0 {
                 return None;
             }
-            let mut new_top = self.top.clone().prev.unwrap();
-            new_top.next = Box::new(None);
-            self.top = new_top;
-            Some(retval)
+            match self.top.clone() {
+                Some(top) => {
+                    let retval = top.val.clone();
+                    let new_top = match *top.clone().prev {
+                        Some(mut n) => {
+                            n.next = Box::new(None);
+                            Some(n)
+                        }
+                        None => None,
+                    };
+                    self.top = new_top;
+                    self.len -= 1;
+                    Some(retval)
+                }
+                None => None,
+            }
+        }
+
+        /// return the length of the stack
+        ///
+        /// # Returns
+        ///
+        /// the length of the stack as a `usize`
+        ///
+        /// # Examples
+        ///
+        /// ```rust
+        /// use stacking::stacks::Stack;
+        /// 
+        /// let mut stack: Stack<i32> = Stack::new();
+        /// stack.push(5);
+        /// assert_eq!(stack.len(), 1);
+        /// stack.pop();
+        /// assert_eq!(stack.len(), 0);
+        /// ```
+        pub fn len(&self) -> usize {
+            self.len
         }
     }
 }
